@@ -36,7 +36,7 @@ class Image(FunctionNode):
             )
         elif args is None:
             image = Image(0)
-            invoke_args = {"image": image, "mask": image}
+            invoke_args = {"input": image, "mask": image}
             super(Image, self).__init__("Image.mask", invoke_args)
         elif isinstance(args, aie.variable_node.VariableNode):
             super(Image, self).__init__(args.func_name, args.invoke_args, args.var_name)
@@ -1545,3 +1545,23 @@ class Image(FunctionNode):
             raise AIEError(AIEErrorCode.ARGS_ERROR, "参数right不能为空")
 
         return FunctionHelper.apply("Image.fastAtan2", "aie.Image", invoke_args)
+
+    def convolve(self, kernel: aie.Kernel) -> aie.Image:
+
+        if kernel is not None and not isinstance(kernel, aie.Kernel):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR,
+                f"kernel 只支持aie.Kernel类型参数, 传入类型为{type(kernel)}",
+            )
+
+        invoke_args = {
+            "image": self,
+            "kernel": kernel,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        if "kernel" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数kernel不能为空")
+
+        return FunctionHelper.apply("Image.convolve", "aie.Image", invoke_args)
