@@ -13,20 +13,24 @@ class FunctionHelper(object):
     def cast(cls, node, kclass):
         if kclass == "aie.Image":
             node.__class__ = aie.Image
-        elif kclass == "aie.Geometry":
-            node.__class__ = aie.Geometry
-        elif kclass == "aie.Feature":
-            node.__class__ = aie.Feature
         elif kclass == "aie.Collection":
             node.__class__ = aie.Collection
         elif kclass == "aie.ImageCollection":
             node.__class__ = aie.ImageCollection
+        elif kclass == "aie.Geometry":
+            node.__class__ = aie.Geometry
+        elif kclass == "aie.Feature":
+            node.__class__ = aie.Feature
         elif kclass == "aie.FeatureCollection":
             node.__class__ = aie.FeatureCollection
-        elif kclass == "aie.Reducer":
-            node.__class__ = aie.Reducer
         elif kclass == "aie.Filter":
             node.__class__ = aie.Filter
+        elif kclass == "aie.Reducer":
+            node.__class__ = aie.Reducer
+        elif kclass == "aie.Terrain":
+            node.__class__ = aie.Terrain
+        elif kclass == "aie.Kernel":
+            node.__class__ = aie.Kernel
         elif kclass in ("int", "float", "bool", "str", "list", "tuple", "dict", "object"):
             pass
         else:
